==> react-filter-utils-0.0.10.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function createFilter(map, valueMap, options = {}) {
  const list = Object.keys(map).map(value => {
    let label = map[value];
    let rest = {};

    if (label && typeof label === 'object') {
      let labelObj = label;
      Object.keys(labelObj).forEach(key => {
        if (key === 'label') label = labelObj[key];else rest[key] = labelObj[key];
      });
    }

    return _objectSpread({
      value,
      label: label
    }, rest);
  });

  const createList = function (values) {
    return list.filter(v => values.includes(v.value));
  };

  const filter = options.filter || function (value) {
    let label = map[value];
    if (!label) return '';
    return typeof label === 'object' ? label.label : label;
  };

  filter.list = list;
  filter.createList = createList;

  if (valueMap) {
    valueMap = Object.keys(valueMap).reduce((p, key) => {
      p[valueMap[key]] = key;
      return p;
    }, {});
  }

  Object.keys(map).forEach(value => {
    if (!value) return;
    const key = valueMap ? valueMap[value] : value;
    if (key === undefined) return;
    filter[key] = value;
  });
  let external = options.external;

  if (external) {
    if (typeof external === 'function') external = external.call(filter, filter);
    external && Object.assign(filter, external);
  }

  return filter;
}

export { createFilter };

==> react-filter-utils-0.0.12.tgz: package/es/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function createFilter(map, valueMap, options = {}) {
  const list = Object.keys(map).map(value => {
    let label = map[value];
    let rest = {};

    if (label && typeof label === 'object') {
      let labelObj = label;
      Object.keys(labelObj).forEach(key => {
        if (key === 'label') label = labelObj[key];else rest[key] = labelObj[key];
      });
    }

    return _objectSpread({
      value,
      label: label
    }, rest);
  });

  const createList = function (values) {
    return list.filter(v => values.includes(v.value));
  };

  const filter = options.filter || function (value) {
    let label = map[value];
    if (!label) return '';
    return typeof label === 'object' ? label.label : label;
  };

  filter.list = list;
  filter.createList = createList;

  if (!valueMap) {
    valueMap = Object.keys(map).reduce((p, key) => {
      if (key) p[key] = key;
      return p;
    }, {});
  }

  Object.keys(valueMap).forEach(key => {
    if (!key) return;
    filter[key] = valueMap[key];
  });
  let external = options.external;

  if (external) {
    if (typeof external === 'function') external = external.call(filter, filter);
    external && Object.assign(filter, external);
  }

  return filter;
}

export { createFilter };
